Learn R Programming

PhytosanitaryCalculator (version 1.1.3)

run_app: Phytosanitary Calculator

Description

A Shiny application for calculating phytosanitary inspection plans based on risks.

Usage

run_app()

Arguments

Value

A Shiny app object.

Details

The application provides sampling plans with minimal sample sizes that keep both producer and importer risks below user-defined levels.