powered by
A Shiny application for calculating phytosanitary inspection plans based on risks.
run_app()
A Shiny app object.
The application provides sampling plans with minimal sample sizes that keep both producer and importer risks below user-defined levels.